utilipy
=======

``utilipy`` is a Python package for non project-specific code. There are modules for making advanced decorators, interfacing with IPython environments, data utilities, making fitting libraries inter-operable, improving astropy units and quantity-enabled functions, and much more.

.. container::

   |astropy| |Build Status| |Codecov| |License| |Code style: black|


Documentation
-------------

|Documentation Status|

The documentation for ``utilipy`` is hosted on `Read the docs <https://readthedocs.org/projects/utilipy/badge/?version=latest>`_.

The `wiki <https://github.com/nstarman/utilipy/wiki>`_ has miscellaneous coding / science tips and tricks.


Installation and Dependencies
-----------------------------

|PyPI|


The easiest way to get *utilipy* is to install with pip. To install with pip::

    pip install utilipy

See the `installation instructions <https://readthedocs.org/projects/utilipy/>`_ in the `documentation <https://readthedocs.org/projects/utilipy/>`_ for more information.


Attribution
-----------

|DOI|

If you make use of this code, please consider citing the Zenodo DOI as a software citation::

   @software{utilipy:zenodo,
     author       = {nstarman},
     title        = {utilipy},
     publisher    = {Zenodo},
     doi          = {10.5281/zenodo.3491011},
     url          = {https://doi.org/10.5281/zenodo.3491011}
   }


License
-------

|License|

Copyright 2018- Nathaniel Starkman and contributors.

``utilipy`` is free software made available under the BSD-3 License. For details see the `LICENSE <https://github.com/nstarman/utilipy/blob/master/LICENSE>`_ file.



.. |astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :target: http://www.astropy.org/

.. |Build Status| image:: https://github.com/nstarman/utilipy/workflows/CI/badge.svg
   :target: https://github.com/nstarman/utilipy/workflows/CI

.. |Code style: black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

.. |Documentation Status| image:: https://readthedocs.org/projects/utilipy/badge/?version=latest
   :target: https://utilipy.readthedocs.io/en/latest/?badge=latest

.. |DOI| image:: https://zenodo.org/badge/192425953.svg
   :target: https://zenodo.org/badge/latestdoi/192425953

.. |License| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause

.. |PyPI| image:: https://badge.fury.io/py/utilipy.svg
   :target: https://badge.fury.io/py/utilipy

.. |Codecov| image:: https://codecov.io/gh/nstarman/utilipy/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/nstarman/utilipy
